@@ -1,31 +1,30 @@
-from .config import Settings, DEFAULTS as DEFAULT_SETTINGS
-
-# main client
 from .client import Blackfynn
-
-# base models
+from .config import DEFAULTS as DEFAULT_SETTINGS
+from .config import Settings
 from .models import (
     BaseNode,
-    Property,
-    Organization,
-    File,
-    DataPackage,
     Collection,
+    DataPackage,
+    Dataset,
+    File,
+    LinkedModelProperty,
     Model,
+    ModelFilter,
+    ModelJoin,
     ModelProperty,
+    ModelSelect,
     ModelTemplate,
+    Organization,
+    Property,
     Record,
     RecordSet,
-    Dataset,
-    RelationshipType,
     Relationship,
     RelationshipSet,
-    Tabular,
-    TabularSchema,
+    RelationshipType,
     TimeSeries,
-    TimeSeriesChannel,
     TimeSeriesAnnotation,
+    TimeSeriesChannel,
 )
 
-__title__ = 'blackfynn'
-__version__ = '2.6.0'
+__title__ = "blackfynn"
+__version__ = "5.0.0"
